@@ -1,5 +1,5 @@
 use v5.40;
-package Minima v0.1.1;
+package Minima v0.2.0;
 1;
 
 __END__
@@ -112,7 +112,7 @@ projects. See L<minima> for full details.
 One of its main features is creating a project from scratch, using
 templates with the recommended structure.
 
-    $ minima new app/
+    $ minima new app
 
 =head1 HISTORY
 
